#
# spec file for package libvshadow
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libvshadow
%define lname	libvshadow1
%define timestamp	20170902
Version:        0~%{timestamp}
Release:        lp150.1.3
Summary:        Library to access the Volume Shadow Snapshot (VSS) format
License:        LGPL-3.0+ and GFDL-1.3+
Group:          System/Filesystems
Url:            https://github.com/libyal/libvshadow/wiki
Source:         https://github.com/libyal/libvshadow/releases/download/%{timestamp}/libvshadow-alpha-%{timestamp}.tar.gz
Source1:        Paper_-_Windowless_Shadow_Snapshots.pdf
Source2:        Slides_-_Windowless_Shadow_Snapshots.pdf
Source3:        Volume_Shadow_Snapshot_VSS_format.pdf
BuildRequires:  fuse-devel
BuildRequires:  gcc
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libbfio) >= 20130908
BuildRequires:  pkgconfig(libcdata) >= 20130407
BuildRequires:  pkgconfig(libcerror) > 20130904
BuildRequires:  pkgconfig(libcfile) >= 20130609
BuildRequires:  pkgconfig(libclocale) >= 20130609
BuildRequires:  pkgconfig(libcnotify) >= 20130609
BuildRequires:  pkgconfig(libcpath) >= 20130609
BuildRequires:  pkgconfig(libcsplit) > 20130904
BuildRequires:  pkgconfig(libcsystem)
BuildRequires:  pkgconfig(libcthreads) >= 20130723
BuildRequires:  pkgconfig(libfdatetime)
BuildRequires:  pkgconfig(libfguid)
BuildRequires:  pkgconfig(libuna) >= 20130609
# These packages are not released as separate packages by upstream.  Internal only
#BuildRequires:  pkgconfig(libcmulti)

%description
Library and tools to access the Volume Shadow Snapshot (VSS) format. The VSS format is used by Windows, as of Vista, to maintain copies of data on a storage media volume.

The devel package contains:

    OSDFC 2012: Paper - Windowless Shadow Snapshots
    OSDFC 2012: Slides - Windowless Shadow Snapshots 
    Volume_Shadow_Snapshot_(VSS)_format.pdf

%package -n %{lname}
Summary:        Library and tools to access the Volume Shadow Snapshot (VSS) format
License:        LGPL-3.0+
Group:          System/Libraries

%description -n %{lname}
Library and tools to access the Volume Shadow Snapshot (VSS) format. The VSS format is used by Windows, as of Vista, to maintain copies of data on a storage media volume.

The package contains %{_docdir}/%{name}:

    OSDFC 2012: Paper - Windowless Shadow Snapshots
    OSDFC 2012: Slides - Windowless Shadow Snapshots 

%package        tools
Summary:        Tools to access the Volume Shadow Snapshot (VSS) format
License:        LGPL-3.0+
Group:          System/Filesystems
Requires:       %{lname} = %{version}

%description    tools
Tools to access the Volume Shadow Snapshot (VSS) format. The VSS format is used by Windows, as of Vista, to maintain copies of data on a storage media volume.
 
%package        devel
Summary:        Development files for %{name}
License:        LGPL-3.0+ and GFDL-1.3+
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        -n python2-%{name}
Summary:        Python 2 binding for libvshadow
License:        LGPL-3.0+
Group:          Development/Languages/Python
Requires:       %{lname} = %{version}
Requires:       python2
BuildRequires:  pkgconfig(python2)
Obsoletes:      python-%{name}

%description    -n python2-%{name}
Python 2 binding for libvshadow.  libvshadow can read windows event files

%package        -n python3-%{name}
Summary:        Python 3 binding for libvshadow
License:        LGPL-3.0+
Group:          Development/Languages/Python
Requires:       %{lname} = %{version}
Requires:       python3
BuildRequires:  pkgconfig(python3)

%description    -n python3-%{name}
Python 3 binding for libvshadow.  libvshadow can read windows event files

%prep
%setup -q -n libvshadow-%{timestamp}
mkdir doc
cp %SOURCE1 .
cp %SOURCE2 .
cp "%SOURCE3" .

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="%{optflags}"
%configure --disable-static --enable-wide-character-type --enable-python2 --enable-python3

make %{?_smp_mflags}

%install
# maintain SLES compatibility
make install DESTDIR="%buildroot"
find %{buildroot} -name '*.la' -exec rm -f {} ';'

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%defattr(-,root,root,-)
%doc AUTHORS COPYING ChangeLog ABOUT-NLS
%doc doc
%{_libdir}/*.so.*

%files tools
%defattr(-,root,root,-)
%{_bindir}/vshadow*
%{_mandir}/man1/*.gz

%files devel
%defattr(-,root,root,-)
%doc AUTHORS COPYING ChangeLog ABOUT-NLS
%doc Paper_-_Windowless_Shadow_Snapshots.pdf
%doc Slides_-_Windowless_Shadow_Snapshots.pdf
%doc Volume_Shadow_Snapshot_*.pdf
%{_includedir}/libvshadow.h
%{_includedir}/libvshadow/
%{_libdir}/*.so
%{_libdir}/pkgconfig/libvshadow.pc
%{_mandir}/man3/*.gz

%files -n python2-%{name}
%defattr(644,root,root,755)
%doc AUTHORS COPYING README
%{python_sitearch}/*.so

%files -n python3-%{name}
%defattr(644,root,root,755)
%doc AUTHORS COPYING README
%{python3_sitearch}/*.so

%changelog
* Mon Nov  6 2017 Greg.Freemyer@gmail.com
- add python3 binding subpackage
* Wed Oct  4 2017 Greg.Freemyer@gmail.com
- rename python-libvshadow to python2-libshadow as expected by singlespec
- remove Provides pyvshadow as it is not versioned
* Mon Oct  2 2017 Greg.Freemyer@gmail.com
- update to v0~20170902
  * applied 2017 update
  * worked on tests
* Thu Feb 16 2017 Greg.Freemyer@gmail.com
- update to v0~20161111
- rename Volume_Shadow_Snapshot_VSS_format.pdf to meet new OBS naming rules
- clean up BuildRequires
* Mon Jan 25 2016 Greg.Freemyer@gmail.com
- update to v0~20160110
  * worked on Python 3 support
  * worked on win2k3 format support
  * introduced new function has_in_volume_data
* Thu Jan  8 2015 Greg.Freemyer@gmail.com
- update to v0~20150106
  * 2015 update - minimal changes
- remove ifdef macros around buildrequires
  * The ifdefs are no longer needed now that all of libyal is in security:forensics
- update BuildRequires based on new packages in OBS
* Thu Dec 11 2014 Greg.Freemyer@gmail.com
- update to v0~20141023
  * bug fix in Python-bindings
  * update man page / info page
- update URL to point to new home on github
- update Source: field to a full URL referring to github
- delete DL-URL comment
- add several BuildRequires to use libyal packages from OBS
* Wed Aug 20 2014 Greg.Freemyer@gmail.com
- add "Requires:  %%lname = %%version" to tools sub-project
- add "Provice:  pyvshadow" to match upstream requires
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- update to v0~20140731
  * updated dependencies
  * worked on Python bindings
  * worked on setup.py
  * changed return value check of libvshadow_store_read_buffer to allow for
  on read size valid read count values
  * subtle bug fix where python file-like object returns an int object
  instead of long object
  * improved error reporting
* Thu Oct  3 2013 Greg.Freemyer@gmail.com
- update to 0~20131003
  * Primarily Windows related improvements
- add libcthread as a standalone BuildRequires
- update BuildRequires for post 13.1 builds
* Fri Aug  2 2013 Greg.Freemyer@gmail.com
- add version levels to BuildRequires to due to a build failure with older libyal packages
* Sat Jul 27 2013 Greg.Freemyer@gmail.com
- update to 0~20130723
  * Changes for stand-alone libbfio build
  * remove unnecessary restriction in library include headers
  * updated dependencies
  * worked on multi-threading support
  * added libvshadow_volume_get_store_identifier function
  * added libcthreads
  * changes to read block descriptors on demand improves vshadowinfo preformance
  * fixes for multiple open/close on the same volume object
  * fixed issue in read buffer due to recent changes
  * added store read from file IO handle function
  * vshadowmount small changes
  * worked on tests
  * worked on vshadowmount Dokan support
- Added buildrequires for gcc
- Use factory libyal packages if possible
- Add BuildRequires for fuse-devel.  Required for vshadowmount in libvshadow-tools to work correctly.
* Wed Apr 17 2013 Greg.Freemyer@gmail.com
- update to 0~20130413
- make specfile more consistent with the other Joachim Metz packages in openSUSE
  * change version from 0.0.0~%%{timestamp} to 0~%%{timestamp}
  * move developer docs to devel package
  * add BuildRequires for the internally provided libs
- add Volume_Shadow_Snapshot_(VSS)_format.pdf to devel package
* Wed Mar 27 2013 Greg.Freemyer@gmail.com
- initial package 0~20130304
